@@ -1,11 +1,26 @@
 # coding=utf-8
+# ASCII ONLY IN THIS FILE THOUGH!!!!!!!
+# Python does some stupid bullshit of respecting LC_ALL over the encoding on the
+# file, so in order to undo Python's ridiculous fucking idiocy, we have to have
+# our own check.
+
 # Copyright 2008, Sean B. Palmer, inamidst.com
 # Copyright 2012, Elsie Powell, http://embolalia.com
-# Copyright © 2012, Elad Alfassa <elad@fedoraproject.org>
+# Copyright 2012, Elad Alfassa <elad@fedoraproject.org>
 #
 # Licensed under the Eiffel Forum License 2.
 
 from __future__ import unicode_literals, absolute_import, print_function, division
+import locale
+import sys
+loc = locale.getlocale()
+if sys.version_info.major > 2:
+    if not loc[1] or 'UTF-8' not in loc[1]:
+        print('WARNING!!! You are running with a non-UTF8 locale environment '
+              'variables (e.g. LC_ALL is set to "C"), which makes Python 3 do '
+              'stupid things. If you get strange errors, please set it to '
+              'something like "en_US.UTF-8".', file=sys.stderr)
+
 
 from collections import namedtuple
 import os
@@ -14,7 +29,7 @@ import time
 import traceback
 import signal
 
-__version__ = '6.2.1'
+__version__ = '6.3.1'
 
 
 def _version_info(version=__version__):
@@ -41,7 +56,6 @@ version_info = _version_info()
 
 def run(config, pid_file, daemon=False):
     import sopel.bot as bot
-    import sopel.web as web
     import sopel.logger
     from sopel.tools import stderr
     delay = 20
@@ -49,7 +63,6 @@ def run(config, pid_file, daemon=False):
     if not config.core.ca_certs:
         stderr('Could not open CA certificates file. SSL will not '
                'work properly.')
-    web.ca_certs = config.core.ca_certs
 
     def signal_handler(sig, frame):
         if sig == signal.SIGUSR1 or sig == signal.SIGTERM:
