@@ -346,6 +346,8 @@ def _send_who(bot, channel):
 @sopel.module.unblockable
 def track_join(bot, trigger):
     if trigger.nick == bot.nick and trigger.sender not in bot.channels:
+        bot.write(('TOPIC', trigger.sender))
+
         bot.privileges[trigger.sender] = dict()
         bot.channels[trigger.sender] = Channel(trigger.sender)
         _send_who(bot, trigger.sender)
@@ -691,3 +693,15 @@ def track_notify(bot, trigger):
         bot.users[trigger.nick] = User(trigger.nick, trigger.user, trigger.host)
     user = bot.users[trigger.nick]
     user.away = bool(trigger.args)
+
+
+@sopel.module.rule('.*')
+@sopel.module.event(events.RPL_TOPIC)
+@sopel.module.priority('high')
+@sopel.module.thread(False)
+@sopel.module.unblockable
+def track_topic(bot, trigger):
+    channel = trigger.args[1]
+    if channel not in bot.channels:
+        return
+    bot.channels[channel].topic = trigger.args[-1]
