@@ -8,6 +8,7 @@ from __future__ import unicode_literals, absolute_import, print_function, divisi
 import json
 import random
 import re
+import requests
 from sopel import web
 from sopel.modules.search import google_search
 from sopel.module import commands
@@ -32,8 +33,7 @@ def get_info(number=None):
         url = 'http://xkcd.com/{}/info.0.json'.format(number)
     else:
         url = 'http://xkcd.com/info.0.json'
-    data = web.get(url)
-    data = json.loads(data)
+    data = requests.get(url).json()
     data['url'] = 'http://xkcd.com/' + str(data['num'])
     return data
 
